@@ -35,10 +35,6 @@
 #include <time.h>
 #include <stdlib.h>
 
-#if !HAVE_O_LARGEFILE
-#define O_LARGEFILE 0
-#endif
-
 static gboolean
 affile_open_file(gchar *name, int flags,
 	     int uid, int gid, int mode,
@@ -239,18 +235,18 @@ affile_sd_deinit(LogPipe *s, GlobalConfig *cfg, PersistentConfig *persist)
 {
   AFFileSourceDriver *self = (AFFileSourceDriver *) s;
 
-  if (persist)
-    {
-      gchar str[32];
-      off_t cur_pos;
-      
-      cur_pos = log_reader_get_pos((LogReader *) self->reader);
-      g_snprintf(str, sizeof(str), "%" G_GINT64_FORMAT, (gint64) cur_pos);
-          
-      persist_config_add_survivor(persist, affile_sd_format_persist_name(self), str);
-    }
   if (self->reader)
     {
+      if (persist)
+        {
+          gchar str[32];
+          off_t cur_pos;
+          
+          cur_pos = log_reader_get_pos((LogReader *) self->reader);
+          g_snprintf(str, sizeof(str), "%" G_GINT64_FORMAT, (gint64) cur_pos);
+              
+          persist_config_add_survivor(persist, affile_sd_format_persist_name(self), str);
+        }
       log_pipe_deinit(self->reader, NULL, NULL);
       log_pipe_unref(self->reader);
       self->reader = NULL;
@@ -302,7 +298,7 @@ struct _AFFileDestWriter
 static gboolean
 affile_dw_reapable(AFFileDestWriter *self)
 {
-  return ((LogWriter *) self->writer)->queue->length == 0;
+  return log_queue_get_length(((LogWriter *) self->writer)->queue) == 0;
 }
 
 static gboolean
@@ -334,7 +330,7 @@ affile_dw_init(LogPipe *s, GlobalConfig *cfg, PersistentConfig *persist)
   if (self->owner->flags & AFFILE_PIPE)
     flags = O_RDWR | O_NOCTTY | O_NONBLOCK | O_LARGEFILE;
   else
-    flags = O_WRONLY | O_CREAT | O_APPEND | O_NOCTTY | O_NONBLOCK | O_LARGEFILE;
+    flags = O_WRONLY | O_CREAT | O_NOCTTY | O_NONBLOCK | O_LARGEFILE;
 
   self->last_open_stamp = time(NULL);
   if (affile_open_file(self->filename->str, flags, 
@@ -346,7 +342,7 @@ affile_dw_init(LogPipe *s, GlobalConfig *cfg, PersistentConfig *persist)
       
       if (!self->writer)
         {
-          self->writer = log_writer_new(LW_FORMAT_FILE, s, &self->owner->writer_options);
+          self->writer = log_writer_new(LW_FORMAT_FILE | ((self->owner->flags & AFFILE_PIPE) ? 0 : LW_ALWAYS_WRITABLE), s, &self->owner->writer_options);
         
           log_pipe_append(&self->super, self->writer);
         }
@@ -361,6 +357,7 @@ affile_dw_init(LogPipe *s, GlobalConfig *cfg, PersistentConfig *persist)
       fdw = fd_write_new(fd);
       if (self->owner->flags & AFFILE_FSYNC)
         fdw->fsync = TRUE;
+      fdw->append = TRUE;
       log_writer_reopen(self->writer, fdw);
     }
   else
@@ -390,7 +387,6 @@ static void
 affile_dw_queue(LogPipe *s, LogMessage *lm, gint path_flags)
 {
   AFFileDestWriter *self = (AFFileDestWriter *) s;
-
   self->last_msg_stamp = time(NULL);
   if (!s->pipe_next && self->last_open_stamp < self->last_msg_stamp - self->time_reopen)
     {
@@ -667,11 +663,11 @@ affile_dd_init(LogPipe *s, GlobalConfig *cfg, PersistentConfig *persist)
     }
   else
     {
-      self->writer = persist_config_fetch(persist, affile_dd_format_persist_name(self));
-      if (self->writer)
+      self->single_writer = persist_config_fetch(persist, affile_dd_format_persist_name(self));
+      if (self->single_writer)
         {
-          affile_dw_set_owner(self->writer, self);
-          log_pipe_init(&self->writer->super, NULL, NULL);
+          affile_dw_set_owner(self->single_writer, self);
+          log_pipe_init(&self->single_writer->super, NULL, NULL);
         }
     }
   
@@ -729,18 +725,19 @@ affile_dd_deinit(LogPipe *s, GlobalConfig *cfg, PersistentConfig *persist)
 {
   AFFileDestDriver *self = (AFFileDestDriver *) s;
 
-  /* writer & writer_hash cannot be non-NULL at the same time */
-  if (self->writer)
+  /* NOTE: we free all AFFileDestWriter instances here as otherwise we'd
+   * have circular references between AFFileDestDriver and file writers */
+  if (self->single_writer)
     {
       g_assert(self->writer_hash == NULL);
 
-      log_pipe_deinit(&self->writer->super, NULL, NULL);
-      persist_config_add(persist, affile_dd_format_persist_name(self), self->writer, affile_dd_destroy_writer);
-      self->writer = NULL;
+      log_pipe_deinit(&self->single_writer->super, NULL, NULL);
+      persist_config_add(persist, affile_dd_format_persist_name(self), self->single_writer, affile_dd_destroy_writer);
+      self->single_writer = NULL;
     }
   else if (self->writer_hash)
     {
-      g_assert(self->writer == NULL);
+      g_assert(self->single_writer == NULL);
       
       g_hash_table_foreach(self->writer_hash, affile_dd_deinit_writer, NULL);
       persist_config_add(persist, affile_dd_format_persist_name(self), self->writer_hash, affile_dd_destroy_writer_hash);
@@ -760,12 +757,12 @@ affile_dd_queue(LogPipe *s, LogMessage *msg, gint path_flags)
 
   if (self->flags & AFFILE_NO_EXPAND)
     {
-      if (!self->writer)
+      if (!self->single_writer)
 	{
 	  next = affile_dw_new(self, g_string_new(self->filename_template->template->str));
 	  if (next && log_pipe_init(&next->super, self->cfg, NULL))
 	    {
-	      self->writer = next;
+	      self->single_writer = next;
 	    }
 	  else
 	    {
@@ -775,7 +772,7 @@ affile_dd_queue(LogPipe *s, LogMessage *msg, gint path_flags)
 	}
       else
         {
-          next = self->writer;
+          next = self->single_writer;
         }
     }
   else
@@ -820,8 +817,8 @@ affile_dd_free(LogPipe *s)
   AFFileDestDriver *self = (AFFileDestDriver *) s;
   
   /* NOTE: this must be NULL as deinit has freed it, otherwise we'd have circular references */
-  g_assert(self->writer == NULL && self->writer_hash == NULL);
-  
+  g_assert(self->single_writer == NULL && self->writer_hash == NULL);
+
   log_template_unref(self->filename_template);
   log_writer_options_destroy(&self->writer_options);
   log_drv_free_instance(&self->super);
