@@ -38,8 +38,6 @@
 
 #if ENABLE_TCP_WRAPPER
 #include <tcpd.h>
-int allow_severity = 0;
-int deny_severity = 0;
 #endif
 
 
