@@ -88,15 +88,19 @@ struct _AFSocketDestDriver
   LogPipe *writer;
   LogWriterOptions writer_options;
 
+  gchar *hostname;
   GSockAddr *bind_addr;
   GSockAddr *dest_addr;
+  gchar *dest_name;
   gint time_reopen;
   guint reconnect_timer;
   SocketOptions *sock_options_ptr;
   gboolean (*setup_socket)(AFSocketDestDriver *s, gint fd);
 };
 
-void afsocket_dd_init_instance(AFSocketDestDriver *self, SocketOptions *sock_options, guint32 flags);
+
+void afsocket_dd_init_instance(AFSocketDestDriver *self, SocketOptions *sock_options, guint32 flags, gchar *dest_name);
 gboolean afsocket_dd_init(LogPipe *s, GlobalConfig *cfg, PersistentConfig *persist);
+void afsocket_dd_free(LogPipe *s);
 
 #endif
