@@ -18,9 +18,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
  */
-
+  
 #ifndef LOGREADER_H_INCLUDED
 #define LOGREADER_H_INCLUDED
 
@@ -82,7 +82,8 @@ off_t log_reader_get_pos(LogReader *self);
 LogPipe *log_reader_new(FDRead *fd, guint32 flags, LogPipe *control, LogReaderOptions *options);
 void log_reader_options_defaults(LogReaderOptions *options);
 void log_reader_options_init(LogReaderOptions *options, GlobalConfig *cfg);
-const gchar *log_reader_find_eom(const gchar *s, gsize n);
+
+gchar *log_reader_find_eom(gchar *s, gsize n);
 
 
 #endif
