@@ -18,20 +18,22 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
  */
-
+  
 #ifndef LOG_WRITER_H_INCLUDED
 #define LOG_WRITER_H_INCLUDED
 
 #include "logpipe.h"
 #include "fdwrite.h"
 #include "templates.h"
+#include "logqueue.h"
 
 /* writer constructor flags */
-#define LW_DETECT_EOF    0x0001
-#define LW_FORMAT_FILE   0x0002
-#define LW_FORMAT_PROTO  0x0004
+#define LW_DETECT_EOF      0x0001
+#define LW_FORMAT_FILE     0x0002
+#define LW_FORMAT_PROTO    0x0004
+#define LW_ALWAYS_WRITABLE 0x0008
 
 /* writer options (set by the user) */
 #define LWO_TMPL_ESCAPE     0x0001
@@ -49,8 +51,8 @@ typedef struct _LogWriterOptions
   /* bitmask of LWOF_* (set by the driver) */
   guint32 flags;
   
-  /* maximum number of entries */
-  gint fifo_size;
+  /* maximum number of entries in the memory based FIFO */
+  gint mem_fifo_size;
   
   /* minimum number of entries to trigger a flush */
   gint flush_lines;
@@ -66,19 +68,28 @@ typedef struct _LogWriterOptions
   gshort ts_format;
   glong zone_offset;
   gshort frac_digits;
+  gint throttle; /* messages per sec, 0 means unlimited */
+  gint time_reopen;
+  gint suppress;
 } LogWriterOptions;
 
 typedef struct _LogWriter
 {
   LogPipe super;
   GSource *source;
-  GQueue *queue;
+  LogQueue *queue;
   guint32 flags;
   guint32 *dropped_messages;
+  guint32 *suppressed_messages;
   GString *partial;
   gint partial_pos;
+  gint throttle_buckets;
   LogPipe *control;
   LogWriterOptions *options;
+  LogMessage *last_msg;
+  guint32 last_msg_count;
+  guint last_msg_timerid;
+
 } LogWriter;
 
 void log_writer_set_options(LogWriter *self, LogPipe *control, LogWriterOptions *options);
