@@ -45,6 +45,7 @@ macros[] =
         { "LEVEL", M_LEVEL },
         { "LEVEL_NUM", M_LEVEL_NUM },
         { "TAG", M_TAG },
+        { "BSDTAG", M_BSDTAG },
         { "PRI", M_PRI },
 
         { "DATE", M_DATE },
@@ -199,6 +200,11 @@ log_macro_expand(GString *result, gint id, guint32 flags, gint ts_format, glong
         g_string_sprintfa(result, "%02x", msg->pri);
         break;
       }
+    case M_BSDTAG:
+      {
+        g_string_sprintfa(result, "%1d%c", (msg->pri & LOG_PRIMASK), (((msg->pri & LOG_FACMASK) >> 3) + 'A'));
+        break;
+      }
     case M_PRI:
       {
         g_string_sprintfa(result, "%d", msg->pri);
@@ -246,13 +252,17 @@ log_macro_expand(GString *result, gint id, guint32 flags, gint ts_format, glong
         /* PID */
         if (msg->msg.len)
           {
-            gchar *start, *end;
+            gchar *start, *end, *colon;
             
-            start = strchr(msg->msg.str, '[');
+            colon = strchr(msg->msg.str, ':');
+            if (!colon)
+              break;
+            
+            start = memchr(msg->msg.str, '[', colon - msg->msg.str);
             if (start)
               {
                 start++;
-                end = strchr(start, ']');
+                end = memchr(start, ']', colon - start);
                 if (end)
                   {
                     result_append(result, start, end-start, !!(flags & MF_ESCAPE_RESULT));
