@@ -278,21 +278,68 @@ setup_creds(void)
 {
   if (chroot_dir) 
     {
+      if (!uid && !gid && getuid() == 0)
+        {
+          msg_notice("You used --chroot and syslog-ng is running as root. It is possible to break out chroot jails in this case", 
+                     NULL);
+        }
+      if (chroot_dir[0] != '/')
+        {
+          msg_error("The directory passed to --chroot must be absolute",
+                    evt_tag_str("chroot", chroot_dir),
+                    NULL);
+          return 0;
+        }
       if (chroot(chroot_dir) < 0) 
 	{
 	  msg_error("Error during chroot()",
+                    evt_tag_str("chroot", chroot_dir),
 	            evt_tag_errno(EVT_TAG_OSERROR, errno),
 	            NULL);
 	  return 0;
 	}
+      if (chdir("/") < 0)
+        {
+	  msg_error("Error setting current directory to the root of the jail",
+                    evt_tag_str("chroot", chroot_dir),
+	            evt_tag_errno(EVT_TAG_OSERROR, errno),
+	            NULL);
+	  return 0;
+        }
     }
 
   if (uid || gid || run_as_user) 
     {
-      setgid(gid);
+      if (setgid(gid) < 0)
+        {
+          msg_error("Error in setgid()",
+                    evt_tag_int("gid", gid),
+	            evt_tag_errno(EVT_TAG_OSERROR, errno),
+                    NULL);
+          if (getuid() == 0)
+            return 0;
+        }
       if (run_as_user)
-        initgroups(run_as_user, gid);
-      setuid(uid);
+        {
+          if (initgroups(run_as_user, gid) < 0)
+            {
+              msg_error("Error in initgroups()",
+                        evt_tag_str("user", run_as_user),
+                        evt_tag_errno(EVT_TAG_OSERROR, errno),
+                        NULL);
+              if (getuid() == 0)
+                return 0;
+            }
+        }
+      if (setuid(uid) < 0)
+        {
+          msg_error("Error in setuid()",
+                    evt_tag_int("uid", uid),
+	            evt_tag_errno(EVT_TAG_OSERROR, errno),
+                    NULL);
+          if (getuid() == 0)
+            return 0;
+        }
     }
   return 1;
 }
@@ -428,7 +475,10 @@ main(int argc, char *argv[])
   /* from now on internal messages are written to the system log as well */
   msg_syslog_started();
   
-  setup_creds();
+  if (!setup_creds())
+    {
+      return 2;
+    }
   setup_std_fds(log_stderr);
   
   rc = main_loop_run(&cfg);
