@@ -67,4 +67,11 @@
 #define O_LARGEFILE 0
 #endif
 
+typedef struct _LogMessage LogMessage;
+typedef struct _GlobalConfig GlobalConfig;
+
+extern GlobalConfig *configuration;
+
+void main_loop_wakeup(void);
+
 #endif
