@@ -1,12 +1,15 @@
-/***************************************************************************
+/*
+ * Copyright (c) 2002-2007 BalaBit IT Ltd, Budapest, Hungary                    
  *
- * Copyright (c) 1999 Balzs Scheidler
- * Copyright (c) 1999-2001 BalaBit IT Ltd.
- * 
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 as published
+ * by the Free Software Foundation.
+ *
+ * Note that this permission is granted for only version 2 of the GPL.
+ *
+ * As an additional exemption you are allowed to compile & link against the
+ * OpenSSL libraries as published by the OpenSSL project. See the file
+ * COPYING for details.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,12 +19,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- * Inspired by nsyslog, originally written by Darren Reed.
- *
- * $Id: utils.h,v 1.9 2001/02/24 12:38:03 bazsi Exp $
- *
- ***************************************************************************/
+ */
 
 #ifndef __UTILS_H_INCLUDED
 #define __UTILS_H_INCLUDED
@@ -31,8 +29,6 @@
 #include <netinet/in.h>
 #include <utmp.h>
 
-char *getshorthostname(char *buf, size_t bufsize);
-
 #ifndef HAVE_INET_ATON
 int inet_aton(const char *cp, struct in_addr *addr);
 #endif
